@@ -2,7 +2,7 @@ package PPI::Xref;
 
 use v5.14;
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 use strict;
 use warnings;
@@ -206,8 +206,11 @@ sub __shadow_filename {
         File::Spec->file_name_is_absolute($filename) ?
         $filename :
         File::Spec->rel2abs($filename);
-    $base =~ s{^/}{};
-    return File::Spec->catfile($shadowdir, $base);
+    my ($vol, $dirs, $file) =
+      File::Spec->splitpath( $base );
+    my @dirs = grep { length } ( $vol, $dirs );
+    my $redir = File::Spec->catdir(@dirs);
+    return File::Spec->catfile($shadowdir, $redir, $file);
 }
 
 # The hash checksum for the file, and the mtime timestamp.
@@ -1597,7 +1600,7 @@ sub __unparse_cache_filename {
     return unless length($cache_filename) > $cache_prefix_length;
 
     my $prefix = substr($cache_filename, 0, $cache_prefix_length);
-    return unless $prefix eq "$cache_directory/";
+    return unless $prefix =~ m{^\Q$cache_directory\E(?:/|\\)$};
 
     return substr($cache_filename, $cache_prefix_length - 1);
 }
